% t3enc.def --- version 1.1
% Copyright 2002 FUKUI Rei
%
% This program may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.2
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.2 or later is part of all distributions of LaTeX 
% version 1999/12/01 or later.
%
% This program consists of all files listed in Manifest.txt.
%
% 2001/10/12: The following bugs have been fixed:
%   \textsubgrave, \textsubacute, \textsubcircum corrected (Peter Zimmermann)
%   modified to be reloadable (Dominique Unruh)
%
% 2001/12/31: Encoding and font shapes modified:
%   \textlhti (\char'245), \textnrleg (\char'256) moved to tipx.
%   \textcrlambda (\char'253), \textlhtlongy (\char'266) added.
%   The above change affects the encoding for the characters with
%   code nos. '245--'266. Macro \textcrlambda deleted.
%   \textgravemacron added.
%   \textscq (\char'261), \textrectangle (\char'277) moved to tipx.
%   \texthtrtaild (\char'243), the tone letter stem (\char'277) added.
%
%   Symbol shapes changed for \textpipe, \textdoublepipe, \textdoublebarpipe
%   (changed to a descender; old versions moved to tipx), \textdownstep,
%   \textupstep (changed to a kind of superscript symbols; old versions
%   move to tipx with new names \textdownfullarrow, \textupfullarrows),
%   \textbullseye (updated; old version moved to tipx),
%   \texthtbardotlessj (updated; old version moved to tipx).
%
% 2002/08/05: The following four commands added:
%   \texthighrise, \textlowrise, \textrisefall, \textfallrise
%
% 2004/03/30: \textdotbreve corrected (defined twice; thanks to W. Lemberg).
%
% Fukui Rei
%
\ProvidesFile{t3enc.def}[2001/12/31 T3 encoding]
\DeclareFontEncoding{T3}{}{}
\DeclareFontSubstitution{T3}{cmr}{m}{n}

% Symbols assigned to the area of numerals.

\DeclareTextSymbol\textbaru{T3}{48}              % Barred U
\DeclareTextSymbol\textbari{T3}{49}              % Barred I
\DeclareTextSymbol\textturnv{T3}{50}             % Turned V
\DeclareTextSymbol\textrevepsilon{T3}{51}        % Reversed Epsilon
\DeclareTextSymbol\textturnh{T3}{52}             % Turned H
\DeclareTextSymbol\textturna{T3}{53}             % Turned A
\DeclareTextSymbol\textturnscripta{T3}{54}       % Turned Script A
\DeclareTextSymbol\textramshorns{T3}{55}         % Ram's Horns
\DeclareTextSymbol\textbaro{T3}{56}              % Barred O
\DeclareTextSymbol\textreve{T3}{57}              % Reversed E

% Symbol assigned to `@'

\DeclareTextSymbol\textschwa{T3}{64}             % Schwa

% Symbols assigned to the area of uppercase letters.

\DeclareTextSymbol\textscripta{T3}{65}           % Script A
\DeclareTextSymbol\textbeta{T3}{66}              % Beta
\DeclareTextSymbol\textctc{T3}{67}               % Curly-tail C
% Eth(68) is defined as \dh, not as \texteth.
\DeclareTextSymbol\textepsilon{T3}{69}           % Epsilon
\DeclareTextSymbol\textphi{T3}{70}               % Phi
\DeclareTextSymbol\textgamma{T3}{71}             % Gamma
\DeclareTextSymbol\texthth{T3}{72}               % Hooktop H
\DeclareTextSymbol\textsci{T3}{73}               % Small Capital I
\DeclareTextSymbol\textctj{T3}{74}               % Curly-tail J
\DeclareTextSymbol\textinvscr{T3}{75}            % Inverted Small Capital R
\DeclareTextSymbol\textturny{T3}{76}             % Turned Y
\DeclareTextSymbol\textltailm{T3}{77}            % Left-tail M (at right)
% Eng(78) is defined as \ng, not as \texteng.
\DeclareTextSymbol\textopeno{T3}{79}             % Open O
\DeclareTextSymbol\textglotstop{T3}{80}          % Glottal Stop
\DeclareTextSymbol\textrevglotstop{T3}{81}       % Reversed Glottal Stop
\DeclareTextSymbol\textfishhookr{T3}{82}         % Fish-hook R
\DeclareTextSymbol\textesh{T3}{83}               % Esh
\DeclareTextSymbol\texttheta{T3}{84}             % Theta
\DeclareTextSymbol\textupsilon{T3}{85}           % Upsilon
\DeclareTextSymbol\textscriptv{T3}{86}           % Script V
\DeclareTextSymbol\textturnm{T3}{87}             % Turned M
\DeclareTextSymbol\textchi{T3}{88}               % Chi
\DeclareTextSymbol\textscy{T3}{89}               % Small Capital Y
\DeclareTextSymbol\textyogh{T3}{90}              % Yogh

% Symbols assigned to the area of lowercase letters.

\DeclareTextSymbol\textscriptg{T3}{103}

% Symbol assigned to "

\DeclareTextSymbol\textprimstress{T3}{34}        % Vertical Stroke (Superior)

% Symbols assigned to : and ;

\DeclareTextSymbol\textlengthmark{T3}{58}        % Length Mark
\DeclareTextSymbol\texthalflength{T3}{59}        % Half-length Mark

% Symbol assigned to |

\DeclareTextSymbol\textpipe{T3}{124}             % Pipe

% Symbols assigned to 224 through 255 (octal '340 -- '377)

\DeclareTextSymbol\textscb{T3}{224}              % Small Capital B
\DeclareTextSymbol\texthtb{T3}{225}              % Hooktop B
\DeclareTextSymbol\texthtd{T3}{226}              % Hooktop D
\DeclareTextSymbol\textrtaild{T3}{227}           % Right-tail D
\DeclareTextSymbol\texthtg{T3}{228}              % Hooktop G
\DeclareTextSymbol\textscg{T3}{229}              % Small Capital G
\DeclareTextSymbol\textcrh{T3}{232}              % Crossed H
\DeclareTextSymbol\textbardotlessj{T3}{233}      % Barred Dotless J
\DeclareTextSymbol\texthtbardotlessj{T3}{234}    % Hooktop Barred Dotless J
\DeclareTextSymbol\textltilde{T3}{235}           % L with Tilde
\DeclareTextSymbol\textbeltl{T3}{236}            % Belted L
\DeclareTextSymbol\textrtaill{T3}{237}           % Right-tail L
\DeclareTextSymbol\textturnmrleg{T3}{238}        % Turned M, Right Leg
\DeclareTextSymbol\textrtailn{T3}{239}           % Right-tail N
\DeclareTextSymbol\textscn{T3}{240}              % Small Capital N
\DeclareTextSymbol\textltailn{T3}{241}           % Left-tail N (at left)
\DeclareTextSymbol\textbullseye{T3}{242}         % Bull's Eye
\DeclareTextSymbol\textrtailr{T3}{243}           % Right-tail R
\DeclareTextSymbol\textturnr{T3}{244}            % Turned R
\DeclareTextSymbol\textturnrrtail{T3}{245}       % Turned R, Right Tail
\DeclareTextSymbol\textscr{T3}{246}              % Small Capital R
\DeclareTextSymbol\textrtails{T3}{249}           % Right-tail S (at left)
\DeclareTextSymbol\textrtailt{T3}{250}           % Right-tail T
\DeclareTextSymbol\textturnw{T3}{251}            % Turned W
\DeclareTextSymbol\textrtailz{T3}{252}           % Right-tail Z
\DeclareTextSymbol\textctz{T3}{253}              % Curly-tail Z
\DeclareTextSymbol\textthorn{T3}{254}            % Thorn
\DeclareTextSymbol\texthvlig{T3}{255}            % H-V Ligature

% Symbols assigned to 192 through 223 (octal '300 -- '337)

\DeclareTextSymbol\textsca{T3}{192}              % Small Capital A
\DeclareTextSymbol\texthtc{T3}{193}              % Hooktop C
\DeclareTextSymbol\textstretchc{T3}{194}         % Stretched C
\DeclareTextSymbol\textdyoghlig{T3}{195}         % D-Yogh Ligature
\DeclareTextSymbol\textrhookschwa{T3}{196}       % Right-hook Schwa
\DeclareTextSymbol\textcloseepsilon{T3}{197}     % Closed Epsilon
\DeclareTextSymbol\textcloserevepsilon{T3}{198}  % Closed Reversed Epsilon
\DeclareTextSymbol\textrhookrevepsilon{T3}{199}  % Right-hook Reversed Epsilon
\DeclareTextSymbol\textbabygamma{T3}{200}        % Baby Gamma
\DeclareTextSymbol\texthtscg{T3}{201}            % Hooktop Small Capital G
\DeclareTextSymbol\texththeng{T3}{202}           % Hooktop Heng
\DeclareTextSymbol\textsch{T3}{203}              % Small Capital H
\DeclareTextSymbol\textiota{T3}{204}             % Iota
\DeclareTextSymbol\textObardotlessj{T3}{205}     % Old Barred Dotless J
\DeclareTextSymbol\texthtk{T3}{206}              % Hooktop K
\DeclareTextSymbol\textscl{T3}{207}              % Small Capital L
\DeclareTextSymbol\textlyoghlig{T3}{208}         % L-Yogh Ligature
\DeclareTextSymbol\textcloseomega{T3}{209}       % Closed Omega
\DeclareTextSymbol\texthtp{T3}{210}              % Hooktop P
\DeclareTextSymbol\texthtq{T3}{211}              % Hooktop Q
\DeclareTextSymbol\textlonglegr{T3}{212}         % Long-leg R
\DeclareTextSymbol\textturnlonglegr{T3}{213}     % Turned Long-leg R
\DeclareTextSymbol\texthtt{T3}{214}              % Hooktop T
\DeclareTextSymbol\textscoelig{T3}{215}          % Small Capital O-E Ligature
\DeclareTextSymbol\textturnt{T3}{216}            % Turned T
\DeclareTextSymbol\textteshlig{T3}{217}          % T-Esh Ligature
\DeclareTextSymbol\textscu{T3}{218}              % Small Capital U
\DeclareTextSymbol\textinvglotstop{T3}{219}      % Inverted Glottal Stop
\DeclareTextSymbol\textbarglotstop{T3}{220}      % Barred Glottal Stop
\DeclareTextSymbol\textbarrevglotstop{T3}{221}   % Barred Reversed Glottal Stop
\DeclareTextSymbol\textcommatailz{T3}{222}       % Comma-tail Z
\DeclareTextSymbol\textwynn{T3}{223}             % Wynn

% Symbols assigned to 160 through 191 (octal '240 -- '277)

\DeclareTextSymbol\textcrb{T3}{160}              % Crossed B
\DeclareTextSymbol\textcrd{T3}{161}              % Crossed D
\DeclareTextSymbol\textctd{T3}{162}              % Curly-tail D
\DeclareTextSymbol\texthtrtaild{T3}{163}         % Hooktop right-tail D
\DeclareTextSymbol\textsce{T3}{164}              % Small Capital E
\DeclareTextSymbol\textg{T3}{165}                % Text G
\DeclareTextSymbol\textlhtlongi{T3}{166}         % Left-hooktop Long I
\DeclareTextSymbol\textvibyi{T3}{167}            % Viby I
\DeclareTextSymbol\textscj{T3}{168}              % Small Capital J
\DeclareTextSymbol\textturnk{T3}{169}            % Turned K
\DeclareTextSymbol\textbarl{T3}{170}             % Barred L
\DeclareTextSymbol\textlambda{T3}{171}           % Lambda
\DeclareTextSymbol\textcrlambda{T3}{172}         % Crossed Lambda %%ADD
\DeclareTextSymbol\textOlyoghlig{T3}{173}        % Old L-Yogh Ligature
\DeclareTextSymbol\textctn{T3}{174}              % Curly-tail N
\DeclareTextSymbol\textturncelig{T3}{175}        % Turned C-E Ligature
\DeclareTextSymbol\textomega{T3}{176}            % Omega
\DeclareTextSymbol\textscomega{T3}{177}          % Small Capital Omega
\DeclareTextSymbol\textctesh{T3}{178}            % Curly-tail Esh
\DeclareTextSymbol\textlhookt{T3}{179}           % Left-hook T
\DeclareTextSymbol\textctt{T3}{180}              % Curly-tail T
\DeclareTextSymbol\texttslig{T3}{181}            % T-S Ligature
\DeclareTextSymbol\textlhtlongy{T3}{182}         % Left-hooktop Long Y %%ADD
\DeclareTextSymbol\textvibyy{T3}{183}            % Viby Y
\DeclareTextSymbol\textctyogh{T3}{184}           % Curly-tail Yogh
\DeclareTextSymbol\textrevyogh{T3}{185}          % Reversed Yogh
\DeclareTextSymbol\textsoftsign{T3}{186}         % Soft Sign
\DeclareTextSymbol\texthardsign{T3}{187}         % Hard Sign
\DeclareTextSymbol\textraiseglotstop{T3}{188}    % Raised Glottal Stop
\DeclareTextSymbol\textlptr{T3}{189}             % Left Pointer
\DeclareTextSymbol\textrptr{T3}{190}             % Right Pointer
\DeclareTextSymbol\texttoneletterstem{T3}{191}   % Tone letter stem

% Symbols assigned to 32, 35, 36, 37 (octal '040, '043, '044, '045)

\DeclareTextSymbol\textceltpal{T3}{32}           % Celtic Palatalization Mark
\DeclareTextSymbol\texthooktop{T3}{35}           % Hooktop
\DeclareTextSymbol\textrthook{T3}{36}            % Right Hook
\DeclareTextSymbol\textpalhook{T3}{37}           % Palatalization Hook

% Symbols assigned to 92, 94, 95 (octal '134, '136, '137)

\DeclareTextSymbol\textrevapostrophe{T3}{92}     % Reversed Apostrophe
\DeclareTextSymbol\textcorner{T3}{94}            % Corner
\DeclareTextSymbol\textopencorner{T3}{95}        % Open Corner

% Symbols assigned to 123, 125, 126, 127 (octal '173, '175, '176, '177)

\DeclareTextSymbol\textdoublepipe{T3}{123}       % Double Pipe
\DeclareTextSymbol\textdoublebarpipe{T3}{125}    % Double-barred Pipe
\DeclareTextSymbol\textrhoticity{T3}{126}        % Rhoticity
\DeclareTextSymbol\textsecstress{T3}{127}        % Vertical Stroke (Inferior)

% Symbols assigned to 146 through 151 (octal '222 -- '227)

\DeclareTextSymbol\textvertline{T3}{146}         % Vertical Line
\DeclareTextSymbol\textdoublevertline{T3}{147}   % Double Vertical Line
\DeclareTextSymbol\textdownstep{T3}{148}         % Down Arrow (Downstep)
\DeclareTextSymbol\textupstep{T3}{149}           % Up Arrow (Upstep)
\DeclareTextSymbol\textglobrise{T3}{150}         % Upward Diagonal Arrow
\DeclareTextSymbol\textglobfall{T3}{151}         % Downward Diagonal Arrow

% The following definitions are common to the T1 encoding.

\DeclareTextSymbol{\i}{T3}{25}
\DeclareTextSymbol{\j}{T3}{26}
\DeclareTextSymbol{\dh}{T3}{68}
\DeclareTextSymbol{\ng}{T3}{78}
\DeclareTextSymbol{\OE}{T3}{215}
\DeclareTextSymbol{\ae}{T3}{230}
\DeclareTextSymbol{\oe}{T3}{247}
\DeclareTextSymbol{\o}{T3}{248}
\DeclareTextSymbol{\th}{T3}{254}

% Accnets and diacritics

\providecommand{\tipaencoding}{\fontencoding{T3}\selectfont}

\@ifundefined{upperaccent}{%
% The following commands are same as the ones in `exaccent.sty'.
{\slshape\xdef\@slshapename{\f@shape}}
{\itshape\xdef\@itshapename{\f@shape}}

\providecommand\upperaccent{\@ifnextchar[{\upper@accent a\empty}%
  {\upper@accent a\empty[\z@]}}
\providecommand\Upperaccent{\@ifnextchar[{\upper@accent b\empty}%
  {\upper@accent b\empty[\z@]}}
\providecommand\loweraccent{\@ifnextchar[{\lower@accent a\empty}%
  {\lower@accent a\empty[\z@]}}
\providecommand\Loweraccent{\@ifnextchar[{\lower@accent b\empty}%
  {\lower@accent b\empty[\z@]}}

\def\upper@accent#1#2[#3]#4#5{{\leavevmode
  \setbox\z@\hbox{#5}\setbox\@ne\hbox{#2%
    \if a#1\char#4\else#4\fi}%
  \ifx\empty#5\empty\box\@ne\else
  \@getaccshift \let\c@lcshift\@pshift
  \dimen\z@\ht\@ne
  \ifdim\ht\@ne>1ex \advance\dimen\z@ -1ex \else
  \ifdim\ht\@ne=\z@ \dimen\z@\dp\@ne \fi\fi
  \vbox{\hsize\wd\z@\offinterlineskip
    \hb@xt@\z@{\@accshift{#3}\hb@xt@\wd\z@{%
     \hss\vbox to \dimen\z@{\hbox{\box\@ne}\vss}\hss}\hss}
    \kern#3
    \hbox{#5}}\fi}}

\def\lower@accent#1#2[#3]#4#5{{\leavevmode
  \setbox\z@\hbox{#5}\setbox\@ne\hbox{#2%
    \if a#1\char#4\else#4\fi}%
  \ifx\empty#5\empty\box\@ne\else
  \@getaccshift \let\c@lcshift\s@bshift
  \dimen\z@\ht\@ne
  \ifdim\ht\@ne>1ex \advance\dimen\z@ -1.1ex \else
  \ifdim\ht\@ne=\z@ \dimen\z@\dp\@ne \fi\fi
  \vtop{\hsize\wd\z@\offinterlineskip
    \hbox{#5}
    \kern#3
    \hbox{\@accshift{#3}\hb@xt@\wd\z@{%
      \hss\vbox to \dimen\z@{\hbox{\box\@ne}\vss}\hss}}}\fi}}

\providecommand\@getaccshift{\def\@accshift##1{}%
  \ifx\f@shape\@slshapename\let\@accshift\@accshiftsl\fi
  \ifx\f@shape\@itshapename\let\@accshift\@accshiftsl\fi}

\providecommand\@accshiftsl[1]{\c@lcshift{#1}\kern-.16667\dimen\@ne}

\providecommand\@pshift[1]{%
  \dimen\@ne-\ht\z@          % get height of the box to be accented
  \advance\dimen\@ne -#1%    % add margin between the letter and accent
  \ifdim\ht\@ne>1ex
    \advance\dimen\@ne 1ex\else
  \ifdim\ht\@ne=\z@
    \advance\dimen\@ne -\dp\@ne\fi\fi}
    
\providecommand\s@bshift[1]{%
  \dimen\@ne\dp\z@                % get depth of the box to be accented
  \ifdim\ht\@ne>\z@
    \advance\dimen\@ne \ht\@ne\fi % add ht of the accent
  \ifdim\ht\@ne>1ex
    \advance\dimen\@ne #1\fi}     % add margin between the letter and accent
}{}

\providecommand\tipaupperaccent{\@ifnextchar[{\upper@accent a\tipaencoding}%
  {\upper@accent a\tipaencoding[\z@]}}
\providecommand\tipaUpperaccent{\@ifnextchar[{\upper@accent b\tipaencoding}%
  {\upper@accent b\tipaencoding[\z@]}}
\providecommand\tipaloweraccent{\@ifnextchar[{\lower@accent a\tipaencoding}%
  {\lower@accent a\tipaencoding[\z@]}}
\providecommand\tipaLoweraccent{\@ifnextchar[{\lower@accent b\tipaencoding}%
  {\lower@accent b\tipaencoding[\z@]}}

%
% Macros for combining glyphs
%
\providecommand\ipaclap[2]{{\setbox\z@\hbox{#1}\dimen\z@\wd\z@
  \setbox\z@\hbox{#2}\ifdim\wd\z@>\dimen\z@ \dimen\z@\wd\z@ \fi
  \leavevmode \hb@xt@\dimen\z@{%
    \hb@xt@\dimen\z@{\hss#1\hss}\hss\hb@xt@\dimen\z@{\hss#2\hss}}}}

%
%  \ipabar
%  #1 character to be barred
%  #2 height of bar position (dimen)
%  #3 bar width (scaling factor to the width of #1)
%  #4 left kern added to the bar (scaling factor to the width of #1)
%  #5 right kern added to the bar (scaling factor to the width of #1)
%
\providecommand\ipabar[5]{{\setbox\z@\hbox{#1}%
  \@getaccshift \let\c@lcshift\b@rshift
  \ifx\f@series\@bfseriesname\let\@halfbar\@bfhalfbar\else
  \ifx\f@family\@sffamilyname\let\@halfbar\@sfhalfbar\fi\fi
  \ooalign{\hidewidth#1\hidewidth\crcr
    \raise#2\hbox{%
      \@accshift{-#2}%
      \kern\@sidegap
      \ifx\empty#4\empty\else\kern#4\wd\z@\fi
      \vrule \@height\@halfbar \@depth\@halfbar \@width #3\wd\z@
      \ifx\empty#5\empty\else\kern#5\wd\z@\fi
      \kern\@sidegap}}}}

{\bfseries\xdef\@bfseriesname{\f@series}}
{\sffamily\xdef\@sffamilyname{\f@family}}

\providecommand\b@rshift[1]{\dimen\@ne#1}
\providecommand\@halfbar{.0355ex}     % 1/2 bar breadth (1/2bar# of cmr10)
\providecommand\@bfhalfbar{.053125ex} % 1/2 bar breadth (1/2bar# of cmbx10)
\providecommand\@sfhalfbar{.065625ex} % 1/2 bar breadth (1/2bar# of cmss10)
\providecommand\@sidegap{.027778em}

%
% Accents and diacritics
%
\DeclareTextCommand\textpolhook{T3}[1]%
  {\tipaloweraccent{12}{#1}}                     % Polish Hook
\DeclareTextCommand\textdoublegrave{T3}[1]%
  {\tipaupperaccent{13}{#1}}                     % Double Grave Accent
\DeclareTextCommand\textroundcap{T3}[1]%
  {\tipaupperaccent{16}{#1}}                     % Round Cap
\DeclareTextCommand\textvbaraccent{T3}[1]%
  {\tipaupperaccent{156}{#1}}                    % Vertical Bar Accent
\DeclareTextCommand\textdoublevbaraccent{T3}[1]%
  {\tipaupperaccent{157}{#1}}                    % Double Vertical Bar Accent

\DeclareTextCommand\textsubgrave{T3}[1]%
  {\loweraccent[.2ex]{14}{#1}}                   % Subscript Grave Accent
\DeclareTextCommand\textsubacute{T3}[1]%
  {\loweraccent[.2ex]{15}{#1}}                   % Subscript Acute Accent
\DeclareTextCommand\textsubcircum{T3}[1]%
  {\loweraccent[.2ex]{2}{#1}}                    % Subscript Circumflex
\DeclareTextCommand\textsubtilde{T3}[1]%
  {\loweraccent[.3ex]{3}{#1}}                    % Subscript Tilde
\DeclareTextCommand\textsubumlaut{T3}[1]%
  {\loweraccent[.3ex]{4}{#1}}                    % Subscript Umlaut
\DeclareTextCommand\textsubring{T3}[1]%
  {\loweraccent[.3ex]{6}{#1}}                    % Subscript Ring
\DeclareTextCommand\textsubwedge{T3}[1]%
  {\loweraccent[.3ex]{7}{#1}}                    % Subscript Wedge
\DeclareTextCommand\textsubbar{T3}[1]%
  {\loweraccent[.3ex]{9}{#1}}                    % Subscript Bar
\DeclareTextCommand\textsubdot{T3}[1]%
  {\loweraccent[.3ex]{10}{#1}}                   % Subscript Dot

\DeclareTextCommand\textsubbridge{T3}[1]%
  {\tipaloweraccent{17}{#1}}                     % Subscript Bridge
\DeclareTextCommand\textinvsubbridge{T3}[1]%
  {\tipaloweraccent{18}{#1}}                     % Inverted Subscript Bridge
\DeclareTextCommand\textsubsquare{T3}[1]%
  {\tipaloweraccent{19}{#1}}                     % Subscript Square
\DeclareTextCommand\textsubrhalfring{T3}[1]%
  {\tipaloweraccent[.2ex]{20}{#1}}               % Subscript Right Half-ring
\DeclareTextCommand\textsublhalfring{T3}[1]%
  {\tipaloweraccent[.2ex]{21}{#1}}               % Subscript Left Half-ring
\DeclareTextCommand\textsubw{T3}[1]%
  {\tipaloweraccent{22}{#1}}                     % Subscript W
\DeclareTextCommand\textoverw{T3}[1]%
  {\tipaupperaccent[.2ex]{22}{#1}}               % Over-W
\DeclareTextCommand\textseagull{T3}[1]%
  {\tipaloweraccent{23}{#1}}                     % Seagull
\DeclareTextCommand\textovercross{T3}[1]%
  {\tipaupperaccent{24}{#1}}                     % Over-cross
\DeclareTextCommand\textsubplus{T3}[1]%
  {\tipaloweraccent[.2ex]{27}{#1}}               % Subscript Plus
\DeclareTextCommand\textraising{T3}[1]%
  {\tipaloweraccent[.2ex]{28}{#1}}               % Raising Sign
\DeclareTextCommand\textlowering{T3}[1]%
  {\tipaloweraccent[.25ex]{29}{#1}}              % Lowering Sign
\DeclareTextCommand\textadvancing{T3}[1]%
  {\tipaloweraccent[.2ex]{30}{#1}}               % Advancing Sign
\DeclareTextCommand\textretracting{T3}[1]%
  {\tipaloweraccent[.2ex]{31}{#1}}               % Retracting Sign

\DeclareTextCommand\textsubarch{T3}[1]%
  {\tipaloweraccent[.2ex]{16}{#1}}               % Subscript Arch
\DeclareTextCommand\textsyllabic{T3}[1]%
  {\tipaloweraccent[.15ex]{34}{#1}}              % Syllabicity Mark
\DeclareTextCommand\textsuperimposetilde{T3}[1]%
  {\ipaclap{#1}{\lower1ex\hbox{\tipaencoding\char38}}} % Superimposed Tilde

\DeclareTextCommand\textmidacute{T3}[1]%
  {\tipaupperaccent{152}{#1}}                    % Macron-Acute Ligature
\DeclareTextCommand\textgravemid{T3}[1]%
  {\tipaupperaccent{153}{#1}}                    % Grave-Macron Ligature
\DeclareTextCommand\textgravecircum{T3}[1]%
  {\tipaupperaccent{154}{#1}}                    % Grave-Wedge Ligature
\DeclareTextCommand\textcircumacute{T3}[1]%
  {\tipaupperaccent{155}{#1}}                    % Circumflex-Acute Ligature

\DeclareTextCommand\textbottomtiebar{T3}[1]%
  {\loweraccent[.3ex]{60}{#1}}                   % Bottom Tie Bar
\DeclareTextCommand\texttoptiebar{T3}[1]%
  {\upperaccent[-.1ex]{62}{#1}}                  % Top Tie Bar

\DeclareTextCommand\textgravedot{T3}[1]%
  {\tipaupperaccent{158}{#1}}                    % Grave Dot Accent
\DeclareTextCommand\textdotacute{T3}[1]%
  {\tipaupperaccent{159}{#1}}                    % Dot Acute Accent
\DeclareTextCommand\textdotbreve{T3}[1]%
  {\tipaupperaccent[-.3ex]{10}%
    {\tipaupperaccent[-.03ex]{8}{#1}}}           % Dot Breve Accent
\DeclareTextCommand\textacutemacron{T3}[1]%
  {\tipaupperaccent[-.15ex]{1}%
    {\tipaupperaccent[-.03ex]{9}{#1}}}           % Acute Macron Accent
\DeclareTextCommand\textgravemacron{T3}[1]%
  {\tipaupperaccent[-.15ex]{0}%
    {\tipaupperaccent[-.03ex]{9}{#1}}}           % Grave Macron Accent
\DeclareTextCommand\textacutewedge{T3}[1]%
  {\tipaupperaccent[-.2ex]{1}%
    {\tipaupperaccent[-.03ex]{7}{#1}}}           % Acute Wedge Accent
\DeclareTextCommand\textcircumdot{T3}[1]%
  {\tipaupperaccent[-.2ex]{2}%
    {\tipaupperaccent[-.1ex]{10}{#1}}}           % Circnumflex Dot Accent
\DeclareTextCommand\texttildedot{T3}[1]%
  {\tipaupperaccent[-.15ex]{3}%
    {\tipaupperaccent[-.1ex]{10}{#1}}}           % Tilde Dot Accent
\DeclareTextCommand\textringmacron{T3}[1]%
  {\tipaupperaccent[-.05ex]{6}%
    {\tipaupperaccent[-.03ex]{9}{#1}}}           % Ring Macron Accent
\DeclareTextCommand\textbrevemacron{T3}[1]%
  {\tipaupperaccent[-.05ex]{8}%
    {\tipaupperaccent[-.03ex]{9}{#1}}}           % Breve Macron Accent

%
% Added on 2002/08/05 (the following four commands)
%
\DeclareTextCommand\texthighrise{T3}[1]{\tipaupperaccent{'230}{#1}}
\DeclareTextCommand\textlowrise{T3}[1]{\tipaupperaccent{'231}{#1}}
\DeclareTextCommand\textrisefall{T3}[1]{\tipaupperaccent{'232}{#1}}
\DeclareTextCommand\textfallrise{T3}[1]{\tipaupperaccent{'233}{#1}}

\providecommand{\@ifacute}[1]{\@ifnextchar'{\@firstoftwo#1}}
\providecommand{\@ifmacron}[1]{\@ifnextchar={\@firstoftwo#1}}
\providecommand{\@ifdot}[1]{\@ifnextchar.{\@firstoftwo#1}}

\DeclareTextCommand{\`}{T3}[0]{\@ifstar{\tipaloweraccent[.2ex]{14}}%
  {\@ifdot{\textgravedot}{\tipaupperaccent{0}}}}
\DeclareTextCommand{\'}{T3}[0]{\@ifstar{\tipaloweraccent[.2ex]{15}}%
  {\@ifmacron{\textacutemacron}{\tipaupperaccent{1}}}}
\DeclareTextCommand{\^}{T3}[0]{\@ifstar{\tipaloweraccent[.2ex]{2}}%
  {\@ifdot{\textcircumdot}{\tipaupperaccent{2}}}}
\DeclareTextCommand{\~}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{3}}%
  {\@ifdot{\texttildedot}{\tipaupperaccent{3}}}}
\DeclareTextCommand{\"}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{4}}%
  {\tipaupperaccent{4}}}
\DeclareTextCommand{\H}{T3}[0]{\@ifstar{\textdoublegrave}%
  {\tipaupperaccent{5}}}
\DeclareTextCommand{\r}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{6}}%
  {\@ifmacron{\textringmacron}{\tipaupperaccent{6}}}}
\DeclareTextCommand{\v}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{7}}%
  {\@ifacute{\textacutewedge}{\tipaupperaccent{7}}}}
\DeclareTextCommand{\u}{T3}[0]{\@ifstar{\tipaloweraccent[.2ex]{16}}%
  {\@ifmacron{\textbrevemacron}{\tipaupperaccent{8}}}}
\DeclareTextCommand{\=}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{9}}%
  {\tipaupperaccent{9}}}
\DeclareTextCommand{\.}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{10}}%
  {\@ifacute{\textdotacute}{\tipaupperaccent{10}}}}
\DeclareTextCommand{\b}{T3}[0]{\tipaloweraccent[.3ex]{9}}
\DeclareTextCommand{\c}{T3}[1]{\tipaloweraccent{11}{#1}}
\DeclareTextCommand{\d}{T3}[0]{\tipaloweraccent[.3ex]{10}}
\DeclareTextCommand{\t}{T3}[0]{\@ifstar{\tipaloweraccent[.3ex]{60}}%
  {\tipaupperaccent[-.1ex]{62}}}
\DeclareTextCommand{\k}{T3}[0]{\textpolhook}

\DeclareTextComposite{\c}{T3}{c}{231}

%
% Symbols made up by TeX macro
%
\DeclareTextCommand\textbarb{T3}[0]{%
  \ipabar{{\tipaencoding b}}{.5ex}{1.1}{}{}}       % Barred B
\DeclareTextCommand\textbarc{T3}[0]{%
  \ipabar{{\tipaencoding c}}{.5ex}{.55}{}{.55}}    % Barred C
\DeclareTextCommand\textbard{T3}[0]{%
  \ipabar{{\tipaencoding d}}{.5ex}{1.1}{}{.05}}    % Barred D
\DeclareTextCommand\textbarg{T3}[0]{%
  \ipabar{{\tipaencoding g}}{.5ex}{1.1}{}{}}       % Barred G
\DeclareTextCommand\textcrg{T3}[0]{%
  \ipabar{{\tipaencoding g}}{-.2ex}{.6}{.4}{}}     % Crossed G
\DeclareTextCommand\textdoublebaresh{T3}[0]{%
  {\setbox\z@\hbox{\textesh}%
  \ipabar{\hb@xt@ \wd\z@{\hss\ipabar{{\textesh}}%
    {.3ex}{1.1}{}{}\hss}}{.75ex}{1.1}{}{}}}        % Double-barred Esh
\DeclareTextCommand\textcrtwo{T3}[0]{%
  {\fontencoding{\encodingdefault}\selectfont
  \ipabar{2}{.6ex}{1.1}{}{}}}                      % Crossed Two
\DeclareTextCommand\textcrinvglotstop{T3}[0]{%
  \ipabar{\textinvglotstop}{1.2ex}{.6}{.2}{.3}}    % Crossed Inv. Glottal Stop 
\DeclareTextCommand\textdoublebarslash{T3}[0]{%
  {\tipaencoding\ipaclap{=}{/}}}                   % Double-barred Slash
\DeclareTextCommand\textraisevibyi{T3}[0]{%
  {\leavevmode
  \setbox\z@\hbox{\textvibyi}\raise\dp\z@\box\z@}} % Raised Viby I

%
% Ligatures made by two symbols combined with an appropriate kerning
%
\DeclareTextCommand\textdzlig{T3}[0]{{%
  \tipaencoding d\kern-.19em z}}             % D-Z Ligature
\DeclareTextCommand\textdctzlig{T3}[0]{{%
  \tipaencoding d\kern-.19em\textctz}}       % D-Curly-tail Z Ligature
\DeclareTextCommand\textctdctzlig{T3}[0]{{%
  \tipaencoding\textctd\kern-.14em\textctz}} % Curly-tail D-Curly-tail Z Lig.
\DeclareTextCommand\texttctclig{T3}[0]{{%
  \tipaencoding t\kern-.17em\textctc}}       % T-Curly-tail C Ligature
\DeclareTextCommand\textcttctclig{T3}[0]{{%
  \tipaencoding\textctt\kern-.16em\textctc}} % Curly-tail T-Curly-tail C Lig.

\endinput
